summaryrefslogtreecommitdiff
path: root/desktop/hotlist.h
diff options
context:
space:
mode:
authorMichael Drake <michael.drake@codethink.co.uk>2017-04-25 11:52:47 +0100
committerMichael Drake <michael.drake@codethink.co.uk>2017-04-25 11:52:47 +0100
commitc47b9f465cfdea1b37e7a5ff7e569290e4a0387e (patch)
treee1f8dd116f202c1cca83d60477dd0717d042b827 /desktop/hotlist.h
parentab53f74788ece5121667bf69375fd3394d984fc9 (diff)
downloadnetsurf-c47b9f465cfdea1b37e7a5ff7e569290e4a0387e.tar.gz
netsurf-c47b9f465cfdea1b37e7a5ff7e569290e4a0387e.tar.bz2
Core hotlist API: Take save path at init, rather than fini.
Diffstat (limited to 'desktop/hotlist.h')
-rw-r--r--desktop/hotlist.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/desktop/hotlist.h b/desktop/hotlist.h
index ef54f6b8b..e38eac1c2 100644
--- a/desktop/hotlist.h
+++ b/desktop/hotlist.h
@@ -40,10 +40,13 @@ struct rect;
* be called before URLs can be added to the hotlist, and before the
* hotlist can be queried to ask if URLs are present in the hotlist.
*
* \param path The path to hotlist file to load
* \return NSERROR_OK on success, appropriate error otherwise
*/
-nserror hotlist_init(const char *path);
+nserror hotlist_init(
+ const char *load_path,
+ const char *save_path);
/**
* Initialise the hotlist manager.
@@ -78,10 +81,9 @@ nserror hotlist_manager_fini(void);
* internal data. After calling this if hotlist is required again,
* hotlist_init must be called.
*
- * \param path The path to save hotlist to
* \return NSERROR_OK on success, appropriate error otherwise
*/
-nserror hotlist_fini(const char *path);
+nserror hotlist_fini(void);
/**
* Add an entry to the hotlist for given URL.
@@ -40,10 +40,13 @@ struct rect;
* hotlist can be queried to ask if URLs are present in the hotlist.
*
- * \param path The path to hotlist file to load
+ * \param load_path The path to load hotlist from.
+ * \param save_path The path to save hotlist to.
* \return NSERROR_OK on success, appropriate error otherwise
*/